@@ -1,8 +1,6 @@
-`print.profileModel` <-
-function (x, print.fit = FALSE, ...) 
-{
+print.profileModel <- function(x, print.fit = FALSE, ...) {
     cat("\nCall: ", deparse(x$call), "\n\n")
-    if (class(x) != "profileModel") 
+    if (!inherits(x, "profileModel"))
         stop("An object of class 'profileModel' has to be supplied.")
     fitted <- x$fit
     BetaNames <- names(x$profiles)[!x$isNA]
@@ -11,7 +9,7 @@ function (x, print.fit = FALSE, ...)
     grid.bounds <- x$grid.bounds
     is.scaled <- !is.null(fitted$X.max.scaleFit)
     if (print.fit) {
-        if (is.scaled) 
+        if (is.scaled)
             cat("Fitted object (the design matrix is scaled by dividing each of its columns by the corresponding maximum):\n")
         else cat("Fitted object:\n")
         print(fitted)
@@ -43,21 +41,21 @@ function (x, print.fit = FALSE, ...)
         print(grid.bounds)
     }
     else {
-        if (!is.null(quant)) 
-            cat("Quantile was set to:", format(quant, digits = getOption("digits")), 
+        if (!is.null(quant))
+            cat("Quantile was set to:", format(quant, digits = getOption("digits")),
                 "\n")
         else {
             cat("Profiling was done over the ranges:\n")
             print(grid.bounds)
         }
     }
-    cat("Grid size:", format(x$gridsize, digits = getOption("digits")), 
+    cat("Grid size:", format(x$gridsize, digits = getOption("digits")),
         "\n")
     cat("\n")
-    cat("Agreement of the objective with fitting method", fitted$call[[1]], 
+    cat("Agreement of the objective with fitting method", fitted$call[[1]],
         ":", x$agreement, "\n")
-    cat("Values of the objective less than", x$zero.bound, "were considered", 
+    cat("Values of the objective less than", x$zero.bound, "were considered",
         0, "\n")
-    if (attr(x, "includes.traces")) 
+    if (attr(x, "includes.traces"))
         cat("The profile traces are included in the object.\n")
 }
